@@ -1,4 +1,4 @@
-from src.three_commas.model.generated_models import BotShow
+from src.three_commas.model.generated_models import Bot
 import json
 
 
@@ -7,6 +7,6 @@ def test_bot_events_are_parsed():
     # filepath = './sample_data/bots/btc/bot_show_with_events_btc.json'
     with open(filepath, 'r+') as f:
         j: dict = json.loads(f.read())
-        bot_show: BotShow = BotShow.of(j)
+        bot_show: Bot = Bot.of(j)
         # TODO
         pass
